# studentclass.py

class Student:
	def __init__(self,name):
		self.name = name
		self.exp = 0
		self.lesson = 0
		#Call Function
		# self.AddEXP(10)

	def Hello(self):
		print('สวัสดีจ้าาาา ผมชื่อ{}'.format(self.name))

	def Coding(self):
		print('{}: กำลังเขียนโปรแกรม..'.format(self.name))
		self.exp += 5
		self.lesson += 1

	def ShowEXP(self):
		print('- {} มีประสบการณ์ {} EXP'.format(self.name,self.exp))
		print('- เรียนไป {} ครั้งแล้ว'.format(self.lesson))

	def AddEXP(self,score):
		self.exp += score # self.exp = self.exp + score
		self.lesson += 1


class SpecialStudent(Student):

	def __init__(self,name,father):
		super().__init__(name)
		self.father = father
		mafia = ['Bill Gates','Thomas Edison']
		if father in mafia:
			self.exp += 100

	def AddEXP(self,score):
		self.exp += (score * 3)
		self.lesson += 1

	def AskEXP(self,score=10):
		print('ครู!! ขอคะแนนพิเศษให้ผมหน่อยสิสัก {} EXP'.format(score))
		self.AddEXP(score)



if __name__ == '__main__':

	print('========1 Jan========')
	student0 = SpecialStudent('Mark Zuckerberg','Bill Gates')
	student0.AskEXP()
	student0.ShowEXP()
	student1 = Student('Albert')
	print(student1.name)
	student1.Hello()

	print('------------')
	student2 = Student('Steve')
	print(student2.name)
	student2.Hello()
	print('========2 Jan========')
	print('------uncle: ใครอยากเรียนโค้ดดิ้ง?---(ให้ 10 exp)----')
	student1.AddEXP(10)

	print('========3 Jan========')
	student1.name = 'Albert Einstein'
	print('ตอนนี้ exp ของแต่ละคนได้เท่าไรกันแล้ว')

	print(student1.name, student1.exp)
	print(student2.name, student2.exp)
	print('========4 Jan========')

	for i in range(5):
		student2.Coding()

	student1.ShowEXP()
	student2.ShowEXP()	


from distutils.core import setup

try:
  with open("README.md","r") as fh:
    long_description = fh.read()
except:
  long_description = 'OOP Learning Example by Wintech Thekop'

setup(
  name = 'wintechschool',         # How you named your package folder (MyLib)
  packages = ['wintechschool'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'OOP Learning Example by Wintech Thekop',   # Give a short description about your library
  long_description=long_description,
  long_description_content_type = "text/markdown",
  author = 'Wintech Thekop',                   # Type in your name
  author_email = 'wintech_thekop@hotmail.com',      # Type in your E-Mail
  url = 'https://github.com/Wintech-thekop/wintechschool',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Wintech-thekop/wintechschool/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['OOP Python', 'THAI', 'Wintech Thekop'],   # Keywords that define your package best
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
